package Devel::ebug::HTTP::View::TT;
use strict;
use warnings;
use Catalyst::View::TT;
use base qw(Catalyst::View::TT);

# ABSTRACT: Template Toolkit view for Devel::ebug::HTTP
our $VERSION = '0.33'; # VERSION


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Devel::ebug::HTTP::View::TT - Template Toolkit view for Devel::ebug::HTTP

=head1 VERSION

version 0.33

=head1 SYNOPSIS

 % perldoc Devel::ebug::HTTP

=head1 DESCRIPTION

This class is private to L<Devel::ebug::HTTP>.

=head1 SEE ALSO

=over 4

=item L<Devel::ebug::HTTP>

=back

=head1 AUTHOR

Original author: Leon Brocard E<lt>acme@astray.comE<gt>

Current maintainer: Graham Ollis E<lt>plicease@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2005-2021 by Leon Brocard.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
